@@ -74,6 +74,14 @@ def main():
             "it will be searched in the checkpoint directory. (default=None)"
         ),
     )
+    parser.add_argument(
+        "--feat_type",
+        type=str,
+        default="feats",
+        help=(
+            "feature type. this is used as key name to read h5 featyre files. "
+        ),
+    )
     parser.add_argument(
         "--verbose",
         type=int,
@@ -200,18 +208,18 @@ def main():
 
             plot_generated_and_ref_2d(
                 out.cpu().numpy(),
-                config["outdir"] + f"/outs/{utt_id}.png",
+                config["outdir"] + f"/plot_mel/{utt_id}.png",
                 ref=mel,
                 origin="lower",
             )
 
             # write feats
-            if not os.path.exists(os.path.join(config["outdir"], "feats")):
-                os.makedirs(os.path.join(config["outdir"], "feats"), exist_ok=True)
+            if not os.path.exists(os.path.join(config["outdir"], "mel")):
+                os.makedirs(os.path.join(config["outdir"], "mel"), exist_ok=True)
 
             write_hdf5(
-                config["outdir"] + f"/feats/{utt_id}.h5",
-                "feats",
+                config["outdir"] + f"/mel/{utt_id}.h5",
+                "mel",
                 out.cpu().numpy().astype(np.float32),
             )
 
